"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const Util_1 = require("../Util");
const BodyParser_1 = __importDefault(require("../BodyParser"));
/** Headers Class
 *
 * Additional Wrapper around Map<string, string>
 * for the key to not be case sensitive.
 */
class Headers extends Map {
    set(key, value) {
        return super.set(key.toLocaleLowerCase(), value);
    }
    get(key) {
        return super.get(key.toLocaleLowerCase());
    }
}
/** Incoming Request
 *
 * Wrapper around the Node:Request or Cloudflare:Request
 */
class IncomingRequest {
    constructor(message) {
        this._headers = new Headers();
        this._url = message.url;
        this._method = message.method.toUpperCase();
        if ((0, Util_1.isCloudflareRequest)(message)) {
            message.headers.forEach((value, key) => {
                this._headers.set(key, value);
            });
        }
        else {
            for (const key in message.headers) {
                let value = message.headers[key];
                if (Array.isArray(value))
                    value = value.join(" ");
                this._headers.set(key, value);
            }
        }
        this._raw = message;
    }
    /** Method Getter
     *
     */
    get method() {
        return this._method;
    }
    /** URL String Getter
     *
     */
    get url() {
        return this._url;
    }
    /** Headers Getter
     *
     */
    get headers() {
        return this._headers;
    }
    async formData() {
        if (this._body === undefined)
            this._body = await (0, BodyParser_1.default)(this._raw);
        return this._body;
    }
}
exports.default = IncomingRequest;
