"use strict";
var __classPrivateFieldSet = (this && this.__classPrivateFieldSet) || function (receiver, state, value, kind, f) {
    if (kind === "m") throw new TypeError("Private method is not writable");
    if (kind === "a" && !f) throw new TypeError("Private accessor was defined without a setter");
    if (typeof state === "function" ? receiver !== state || !f : !state.has(receiver)) throw new TypeError("Cannot write private member to an object whose class did not declare it");
    return (kind === "a" ? f.call(receiver, value) : f ? f.value = value : state.set(receiver, value)), value;
};
var __classPrivateFieldGet = (this && this.__classPrivateFieldGet) || function (receiver, state, kind, f) {
    if (kind === "a" && !f) throw new TypeError("Private accessor was defined without a getter");
    if (typeof state === "function" ? receiver !== state || !f : !state.has(receiver)) throw new TypeError("Cannot read private member from an object whose class did not declare it");
    return kind === "m" ? f : kind === "a" ? f.call(receiver) : f ? f.value : state.get(receiver);
};
var _OutgoingResponse_server, _OutgoingResponse_status, _OutgoingResponse_headers, _OutgoingResponse_body, _OutgoingResponse_redirect;
Object.defineProperty(exports, "__esModule", { value: true });
const node_stream_1 = require("node:stream");
const Util_1 = require("../Util");
/** Outgoing Response
 *
 * Wrapper around the Node:Response or
 * returns the Cloudflare:Response
 */
class OutgoingResponse extends node_stream_1.Transform {
    /** Stringify Encoded Data
     *
     * @param {any} data
     * @param {string} encode
     * @returns {string}
     */
    static _stringify(data, encode) {
        //Test if not string.
        if (typeof data !== "string") {
            //Test if it has toString method
            if (typeof data.toString === "function") {
                //Test if accepts encdoding.
                if (data.toString.length >= 1) {
                    return data.toString(encode);
                }
                else {
                    if (encode)
                        console.warn(`Encoding '${encode}' ignored!`);
                    return data.toString();
                }
            }
            return String(data);
        }
        return data;
    }
    /** Encode to Uint8Array
     *
     * @param {any} data
     * @param {string} encode
     * @returns {Uint8Array}
     */
    static _encode(data, encode) {
        return OutgoingResponse.encoder.encode(OutgoingResponse._stringify(data, encode));
    }
    /** Proto Response Constructor
     *
     */
    constructor(response) {
        super();
        //Strict Private
        _OutgoingResponse_server.set(this, void 0);
        _OutgoingResponse_status.set(this, void 0);
        _OutgoingResponse_headers.set(this, void 0);
        _OutgoingResponse_body.set(this, void 0);
        _OutgoingResponse_redirect.set(this, void 0);
        __classPrivateFieldSet(this, _OutgoingResponse_status, 200, "f");
        __classPrivateFieldSet(this, _OutgoingResponse_headers, new Map(), "f");
        __classPrivateFieldSet(this, _OutgoingResponse_body, [], "f");
        __classPrivateFieldSet(this, _OutgoingResponse_server, response, "f");
        //Default headers
        __classPrivateFieldGet(this, _OutgoingResponse_headers, "f").set("Referrer-Policy", "strict-origin");
    }
    /** Transform Data Override
     *
     * @param {any} data
     * @param {string} encode
     * @param {Function} callback
     */
    _transform(data, encode, callback) {
        this.working = true;
        if (data instanceof Uint8Array)
            __classPrivateFieldGet(this, _OutgoingResponse_body, "f").push(data);
        else
            __classPrivateFieldGet(this, _OutgoingResponse_body, "f").push(OutgoingResponse._encode(data, encode));
        callback();
    }
    /** Flush Override
     *
     * @param callback
     */
    _flush(callback) {
        this.working = false;
        this.emit("close");
        callback();
    }
    /** Has Commited
     *
     * @returns
     */
    commited() {
        return this.working !== undefined;
    }
    /** Status Getter
     *
     */
    get status() {
        return __classPrivateFieldGet(this, _OutgoingResponse_status, "f");
    }
    /** Status Setter
     *
     */
    set status(value) {
        __classPrivateFieldSet(this, _OutgoingResponse_status, value, "f");
    }
    /** Headers Getter
     *
     */
    get headers() {
        return __classPrivateFieldGet(this, _OutgoingResponse_headers, "f");
    }
    /** Flush Response
     *
     * @returns {Promise<Response>}
     */
    async flush() {
        while (this.working)
            (0, Util_1.sleep)();
        if (__classPrivateFieldGet(this, _OutgoingResponse_server, "f")) {
            if (__classPrivateFieldGet(this, _OutgoingResponse_redirect, "f")) {
                __classPrivateFieldGet(this, _OutgoingResponse_server, "f").writeHead(__classPrivateFieldGet(this, _OutgoingResponse_status, "f"), JSON.stringify({ Location: __classPrivateFieldGet(this, _OutgoingResponse_redirect, "f") }));
            }
            else {
                __classPrivateFieldGet(this, _OutgoingResponse_server, "f").statusCode = __classPrivateFieldGet(this, _OutgoingResponse_status, "f");
                for (const [key, value] of __classPrivateFieldGet(this, _OutgoingResponse_headers, "f").entries()) {
                    __classPrivateFieldGet(this, _OutgoingResponse_server, "f").setHeader(key, value);
                }
                for (const chunk of __classPrivateFieldGet(this, _OutgoingResponse_body, "f"))
                    __classPrivateFieldGet(this, _OutgoingResponse_server, "f").write(chunk);
                __classPrivateFieldGet(this, _OutgoingResponse_server, "f").end();
            }
            return;
        }
        if (__classPrivateFieldGet(this, _OutgoingResponse_redirect, "f")) {
            return Response.redirect(__classPrivateFieldGet(this, _OutgoingResponse_redirect, "f"), __classPrivateFieldGet(this, _OutgoingResponse_status, "f"));
        }
        const headers = {};
        for (const [name, value] of __classPrivateFieldGet(this, _OutgoingResponse_headers, "f").entries())
            headers[name] = value;
        return new Response(new Blob(__classPrivateFieldGet(this, _OutgoingResponse_body, "f")), {
            status: this.status,
            headers: headers
        });
    }
    /** Redirect Resposne
     *
     * @param {URL} url
     * @param {number} status
     */
    redirect(url, status = 302) {
        __classPrivateFieldSet(this, _OutgoingResponse_redirect, url, "f");
        __classPrivateFieldSet(this, _OutgoingResponse_status, status, "f");
        this.working = false;
    }
}
_OutgoingResponse_server = new WeakMap(), _OutgoingResponse_status = new WeakMap(), _OutgoingResponse_headers = new WeakMap(), _OutgoingResponse_body = new WeakMap(), _OutgoingResponse_redirect = new WeakMap();
OutgoingResponse.encoder = new TextEncoder();
exports.default = OutgoingResponse;
