/// <reference types="@cloudflare/workers-types/2023-07-01" />
/** /Context/Query
 *
 * @author Alex Malotky
 */
import { Object as ObjectValue } from "../Validation/Type";
import DataObject, { TypeOf, DataConstraints, ObjectProperties } from "../Validation";
interface QueryConstraints<P extends ObjectProperties> {
    groupBy?: Array<keyof P>;
    orderBy?: Record<keyof P, "ASC" | "DESC">;
    limit?: number;
    offset?: number;
}
/** Database Query Builder
 *
 * Currntly only works with Cloudflare D1Database
 */
export default class QueryBuilder<P extends ObjectProperties> {
    private _db;
    private _obj;
    constructor(db: D1Database, object: DataObject<P>);
    private get db();
    /** Insert Value into Database
     *
     * @param {Object} value
     */
    insert(value: ObjectValue<keyof P>): Promise<void>;
    /** Update Value in Database
     *
     * @param {Object} value
     * @param {ObjectDefaults} constraints
     */
    update(value: ObjectValue<keyof P>, constraints?: DataConstraints<keyof P>): Promise<void>;
    /** Delete Value in Database
     *
     */
    delete(constraints?: DataConstraints<keyof P>): Promise<void>;
    /** Get First Value from Database
     *
     * @param {ObjectDefaults} constraints
     */
    get(constraints?: DataConstraints<keyof P>): Promise<TypeOf<DataObject<P>> | null>;
    /** Get ALl Values from Database
     *
     * @param {ObjectDefaults} constraints
     */
    getAll(constraints?: DataConstraints<keyof P>, filter?: QueryConstraints<P>): Promise<TypeOf<DataObject<P>>[]>;
}
export {};
