/** /Routing/Layer.ts
 *
 * @author Alex Malotky
 */
import Context from "../Context";
import { PathToRegexpOptions } from "path-to-regexp";
export type Middleware = (context: Context) => Promise<void> | void;
/** Single Routing Layer
 *
 */
export default class Layer {
    private _shortcut;
    private _handler;
    private _regex;
    private _keys;
    private _path;
    private _prefix;
    private _opts;
    constructor(middleware: Middleware);
    constructor(path: string, middleware: Middleware);
    constructor(path: string, opts: PathToRegexpOptions, middleware: Middleware);
    /** Handle Routing
     *
     * @param {Context} context
     */
    handle(context: Context): Promise<void>;
    /** Match Routing
     *
     * @param {Context} context
     * @returns {boolean}
     */
    protected match(context: Context): boolean;
    /** Path Getter
     *
     */
    get path(): string;
    /** Path Setter
     *
     */
    set path(value: string);
    /** Get Total Path
     *
     * @returns {string}
     */
    totalPath(): string;
    /** Set Prefix
     *
     * @param {string} value
     */
    prefix(value: string): void;
    /** Update Options
     *
     * @param {PathToRegexpOptions} value
     */
    update(value: PathToRegexpOptions): void;
}
