/** /Routing/Layer.ts
 *
 * @author Alex Malotky
 */
import Context from "../Context";
import Layer, { Middleware } from "./Layer";
/** Method Stack Class
 *
 * Wrapper around array to make adding methods to the stack easier.
 */
declare class Stack extends Array<{
    name: string;
    layer: Layer;
}> {
    /** Add Method Layer
     *
     * @param {string} name
     * @param {Layer} layer
     */
    add(name: string, layer: Layer): void;
}
/** Router Layer
 *
 * Array<Layer> seperated by Method Types.
 */
export default class Router extends Layer {
    protected _methods: Stack;
    /** Constructor
     *
     * @param {any} options
     */
    constructor(path?: string);
    /** Handle Routing Override
     *
     * @param {Context} context
     */
    handle(context: Context): Promise<void>;
    /** Filter Arguments into Layer
     *
     * @param {IArguments} args
     * @returns {Layer}
     */
    private _filter;
    /** Set Prefix Override
     *
     * @param {string} value
     */
    prefix(value: string): void;
    /** Use Middleware Method
     *
     * @param {Middleware|Layer} middleware
     * @returns {this}
     */
    use(middleware: Middleware | Layer): this;
    use(path: string, handler: Middleware | Layer): this;
    /** Add Get Method Handler
     *
     * @param {string} path  = "/"
     * @param {Middleware|Layer} handler
     * @returns {this}
     */
    get(handler: Middleware | Layer): this;
    get(path: string, handler: Middleware | Layer): this;
    /** Add Head Method Handler
     *
     * @param {string} path  = "/"
     * @param {Middleware|Layer} handler
     * @returns {this}
     */
    head(handler: Middleware | Layer): this;
    head(path: string, handler: Middleware | Layer): this;
    /** Add Post Method Handler
     *
     * @param {string} path  = "/"
     * @param {Middleware|Layer} handler
     * @returns {this}
     */
    post(handler: Middleware | Layer): this;
    post(path: string, handler: Middleware | Layer): this;
    /** Add Set Method Handler
     *
     * @param {string} path  = "/"
     * @param {Middleware|Layer} handler
     * @returns {this}
     */
    put(handler: Middleware | Layer): this;
    put(path: string, handler: Middleware | Layer): this;
    /** Add Delete Method Handler
     *
     * @param {string} path  = "/"
     * @param {Middleware|Layer} handler
     * @returns {this}
     */
    delete(handler: Middleware | Layer): this;
    delete(path: string, handler: Middleware | Layer): this;
    /** Add Options Method Handler
     *
     * @param {string} path  = "/"
     * @param {Middleware|Layer} handler
     * @returns {this}
     */
    options(handler: Middleware | Layer): this;
    options(path: string, handler: Middleware | Layer): this;
    /** Add Patch Method Handler
     *
     * @param {string} path  = "/"
     * @param {Middleware|Layer} handler
     * @returns {this}
     */
    patch(handler: Middleware | Layer): this;
    patch(path: string, handler: Middleware | Layer): this;
    /** Add All Method Handler
     *
     * @param {string} path  = "/"
     * @param {Middleware|Layer} handler
     * @returns {this}
     */
    all(handler: Middleware | Layer): this;
    all(path: string, handler: Middleware | Layer): this;
}
export {};
