"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const Layer_1 = __importDefault(require("./Layer"));
const Util_1 = require("../Util");
//Router Error Thrower
const ROUTER_ERROR = () => { throw new Error("_handler called from Router!"); };
/** Method Stack Class
 *
 * Wrapper around array to make adding methods to the stack easier.
 */
class Stack extends Array {
    /** Add Method Layer
     *
     * @param {string} name
     * @param {Layer} layer
     */
    add(name, layer) {
        this.push({ name, layer });
    }
}
/** Router Layer
 *
 * Array<Layer> seperated by Method Types.
 */
class Router extends Layer_1.default {
    /** Constructor
     *
     * @param {any} options
     */
    constructor(path = "/") {
        super(path, { end: false }, ROUTER_ERROR);
        this._methods = new Stack();
    }
    /** Handle Routing Override
     *
     * @param {Context} context
     */
    async handle(context) {
        if (this.match(context)) {
            for (const { name, layer } of this._methods) {
                if (name === "MIDDLEWARE") {
                    await layer.handle(context);
                    if (context.response.commited())
                        return;
                }
                else if (name === context.method || name === "ALL") {
                    await layer.handle(context);
                    if (context.response.commited())
                        return;
                }
            }
        }
    }
    /** Filter Arguments into Layer
     *
     * @param {IArguments} args
     * @returns {Layer}
     */
    _filter(args) {
        let output;
        switch (typeof args[0]) {
            case "function":
                output = new Layer_1.default("/", args[0]);
                break;
            case "string":
                switch (typeof args[1]) {
                    case "function":
                        output = new Layer_1.default(args[0], args[1]);
                        break;
                    case "object":
                        if (args[1] instanceof Layer_1.default) {
                            output = args[1];
                            output.path = (0, Util_1.joinPath)(args[0], args[1].path);
                            break;
                        }
                    default:
                        throw new TypeError("Middlware must be a function or Layer!");
                }
                break;
            case "object":
                if (args[0] instanceof Layer_1.default) {
                    output = args[0];
                    break;
                }
                throw new TypeError("Middleware object must be an instance of Layer.");
            default:
                throw new TypeError("Path must be a string!");
        }
        output.prefix(this.totalPath());
        return output;
    }
    /** Set Prefix Override
     *
     * @param {string} value
     */
    prefix(value) {
        super.prefix(value);
        for (const { layer } of this._methods) {
            layer.prefix(this.totalPath());
        }
    }
    use() {
        this._methods.add("MIDDLEWARE", this._filter(arguments));
        return this;
    }
    get() {
        this._methods.add("GET", this._filter(arguments));
        return this;
    }
    head() {
        this._methods.add("HEAD", this._filter(arguments));
        return this;
    }
    post() {
        this._methods.add("POST", this._filter(arguments));
        return this;
    }
    put() {
        this._methods.add("PUT", this._filter(arguments));
        return this;
    }
    delete() {
        this._methods.add("DELETE", this._filter(arguments));
        return this;
    }
    options() {
        this._methods.add("OPTIONS", this._filter(arguments));
        return this;
    }
    patch() {
        this._methods.add("PATCH", this._filter(arguments));
        return this;
    }
    all() {
        this._methods.add("ALL", this._filter(arguments));
        return this;
    }
}
exports.default = Router;
