/** /Routing
 *
 * @author Alex Malotky
 */
import Context from "../Context";
import Router from "./Router";
/** Handler Type
 *
 */
export type Handler = (context: Context) => Promise<void> | void;
/** Error Handler Type
 *
 */
type ErrorHandler = (error: any, context: Context) => Promise<void> | void;
/** Routing Class
 *
 * Top Level Wrapper around Router class that
 * handles errors.
 */
export default class Routing extends Router {
    private notFoundHandler;
    private errorHandler;
    /** Routing Constructor
     *
     */
    constructor();
    /** Routing Handler Wrappper
     *
     * Made to easier seperate from routing/not found error handler
     * and normal error handler.
     *
     * @param {Context} context
     * @param {any} error
     * @returns {Promise<Response>}
     */
    route(context: Context, error?: any): Promise<Response | undefined>;
    /** Handle Routing Override
     *
     * @param {Context} context
     * @returns {Promise<void>}
     */
    handle(context: Context): Promise<void>;
    /** Not Found Handler Setter
     *
     * @param {Handler} handler
     */
    notFound(handler: Handler): void;
    /** Error Handler Setter
     *
     * @param {ErrorHandler} handler
     */
    error(handler: ErrorHandler): void;
}
export {};
