"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
/** /Static
 *
 * @author Alex Malotky
 */
const Node_1 = require("./Node");
const MimeTypes_1 = __importDefault(require("./MimeTypes"));
const Layer_1 = __importDefault(require("./Routing/Layer"));
const Util_1 = require("./Util");
/** Static Content Handler
 *
 * @param {string} route
 * @param {sting} dir
 * @returns {Layer}
 */
function Static(route, dir) {
    const fs = (0, Node_1.nodeImport)("fs");
    const path = (0, Node_1.nodeImport)("node:path");
    /** Pipe File Promise Wrapper
     *
     * @param {string} file
     * @param {OutgoingResponse} response
     * @returns {Promise<void>}
     */
    function pipeWrappper(file, response) {
        return new Promise((res) => {
            fs.createReadStream(file)
                .pipe(response)
                .on("close", res);
        });
    }
    /** Handle Static File
     *
     * @param {Context} ctx
     */
    async function handleStaticFile(ctx) {
        if (ctx.method !== "GET" && ctx.method !== "HEAD") {
            return;
        }
        const target = path.join(dir, ctx.params.get("query"));
        if (fs.existsSync(target) === false) {
            return;
        }
        const stats = fs.statSync(target);
        if (stats.isDirectory()) {
            return;
        }
        ctx.response.headers.set('Content-Type', (0, MimeTypes_1.default)(target));
        ctx.response.headers.set("Content-Length", stats.size.toString());
        ctx.response.headers.set('Content-Security-Policy', "default-src 'none'");
        ctx.response.headers.set('X-Content-Type-Options', "nosniff");
        await pipeWrappper(target, ctx.response);
        ctx.end();
    }
    ;
    return new Layer_1.default((0, Util_1.joinPath)(route, "/*query"), { end: false }, handleStaticFile);
}
exports.default = Static;
