"use strict";
/** /Util
 *
 * @author Alex Malotky
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.joinPath = exports.inNodeEnvironment = exports.inCloudfareWorker = exports.isCloudflareRequest = exports.dictionaryInclude = exports.sleep = exports.HEADER_KEY = exports.HEADER_VALUE = void 0;
exports.HEADER_VALUE = "application/json";
exports.HEADER_KEY = "Update-Type";
/** Sleep
 *
 * @param {number} n
 */
function sleep(n = 1) {
    return new Promise(res => {
        setTimeout(res, n);
    });
}
exports.sleep = sleep;
/** Dictionary Include
 *
 * @param {Dictionary} dictionary
 * @param {string} name
 * @returns {boolean}
 */
function dictionaryInclude(dictionary, name) {
    for (let test in dictionary) {
        if (test === name)
            return true;
    }
    return false;
}
exports.dictionaryInclude = dictionaryInclude;
/** Is Cloudfare Request
 *
 * @param {any} request
 * @returns {boolean}
 */
function isCloudflareRequest(request) {
    return typeof request.formData === "function";
}
exports.isCloudflareRequest = isCloudflareRequest;
/** Detect Cloudflare Environment
 *
 */
function inCloudfareWorker() {
    return typeof navigator !== "undefined" && navigator.userAgent === 'Cloudflare-Workers';
}
exports.inCloudfareWorker = inCloudfareWorker;
/** Detect Node Environment
 *
 */
function inNodeEnvironment() {
    return (typeof process !== 'undefined') && (process.release.name === 'node');
}
exports.inNodeEnvironment = inNodeEnvironment;
/** Join Paths
 *
 * @param paths
 */
function joinPath(...paths) {
    return "/" + paths.map(part => {
        if (part === "/")
            return "";
        if (part.charAt(0) === "/")
            part = part.slice(1);
        if (part.charAt(part.length - 1) === "/")
            part = part.slice(-1);
        return part;
    }).filter(s => s).join("/");
}
exports.joinPath = joinPath;
