"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.BooleanName = void 0;
/** /Validation/Boolean
 *
 * @author Alex Malotky
 */
const Type_1 = require("./Type");
const Empty_1 = require("./Type/Empty");
//Boolean Format Name
exports.BooleanName = "boolean";
/** Boolean Validator
 *
 */
class BooleanValidator extends Type_1.TypeValidator {
    constructor(value) {
        if (value)
            value = convertToBoolean(value);
        super(exports.BooleanName, formatBooleanGenerator(value));
    }
}
exports.default = BooleanValidator;
/** FOrmat Boolean Genderator
 *
 * @param {boolean} ifEmpty
 * @returns {Function}
 */
function formatBooleanGenerator(ifEmpty) {
    /** Format Boolean
     *
     * @param {unkown} value
     * @return {boolean}
     */
    return function formatBoolean(value) {
        if (value === undefined) {
            if (ifEmpty === undefined)
                throw new Empty_1.EmptyError(`Expected ${exports.BooleanName} Value!`);
            return ifEmpty;
        }
        else if (value == null) {
            return ifEmpty || false;
        }
        else {
            return convertToBoolean(value);
        }
    };
}
/** Convert To Boolean
 *
 * @param {unknown} value
 * @returns {boolean}
 */
function convertToBoolean(value) {
    switch (typeof value) {
        case "string":
            return value.toLocaleLowerCase() === "true" || value === "1";
        case "bigint":
            value = Number(value);
        case "number":
            return value === 1;
        case "boolean":
            return value;
        case "object":
            if (value === null) {
                return false;
            }
        default:
            throw new TypeError(`Invalid type '${typeof value}' for Boolean!`);
    }
}
