"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ListName = void 0;
/** /Validation/List
 *
 * @author Alex Malotky
 */
const Type_1 = require("./Type");
const Empty_1 = require("./Type/Empty");
//List Format Name
exports.ListName = "List";
/** List Validator
 *
 */
class ListValidator extends Type_1.TypeValidator {
    constructor(type, seperator, value) {
        if (value) {
            if (!Array.isArray(value))
                throw new TypeError("Default value is not a List!");
            value = value.map((v) => type.run(v));
        }
        super(exports.ListName, formatListGenerator(type, seperator, value));
        this._seperator = seperator;
    }
    simplify(value) {
        if (this._seperator === undefined) {
            return JSON.stringify(value);
        }
        return value.join(this._seperator);
    }
}
exports.default = ListValidator;
/** Format List Generator
 *
 * @param {Type} type
 * @param {string} seperator
 * @param {List} ifEmpty
 * @returns {Function}
 */
function formatListGenerator(type, seperator, ifEmpty) {
    /** Format List
     *
     * @param {unknown} input
     * @returns {List<Type>}
     */
    return function formatList(input) {
        return (0, Empty_1.emptyHandler)(input, (value) => objectify(input, seperator).map(value => type.run(value)), exports.ListName, ifEmpty);
    };
}
/** List Objectifier
 *
 * @param {unkown} value
 * @returns {Array<unknown>}
 */
function objectify(value, seperator = null) {
    switch (typeof value) {
        case "string":
            if (seperator === null)
                return objectify(JSON.parse(value));
            else
                return value.split(seperator);
        case "object":
            if (Array.isArray(value))
                return value;
        default:
            throw new TypeError(`Invalid type list: '${value}'`);
    }
}
