"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.isFile = exports.formatFile = void 0;
/** Validation/Types/File
 *
 * @author Alex Malotky
 */
const Empty_1 = require("./Empty");
/** String to Blob
 *
 * Taken From: https://stackoverflow.com/questions/4998908/convert-data-uri-to-file-then-append-to-formdata
 *
 * @param {string} dataURI
 * @returns {Blob}
 */
function dataURIToBlob(dataURI) {
    // convert base64/URLEncoded data component to raw binary data held in a string
    var byteString;
    if (dataURI.split(',')[0].indexOf('base64') >= 0)
        byteString = atob(dataURI.split(',')[1]);
    else
        byteString = unescape(dataURI.split(',')[1]);
    // separate out the mime component
    var mimeString = dataURI.split(',')[0].split(':')[1].split(';')[0];
    // write the bytes of the string to a typed array
    var ia = new Uint8Array(byteString.length);
    for (var i = 0; i < byteString.length; i++) {
        ia[i] = byteString.charCodeAt(i);
    }
    return new Blob([ia], { type: mimeString });
}
/** Text String To Blob
 *
 * @param {string} value
 * @returns {Blob}
 */
function textToBlob(value) {
    const byteArray = new Uint8Array(value.length);
    for (let i = 0; i < value.length; i++) {
        byteArray[i] = value.charCodeAt(i);
    }
    return new Blob([byteArray], { type: "text/plain" });
}
/** Format Email
 *
 * Used to format / sanitize email input.
 *
 * @param {unknown} value
 * @returns {Email}
 */
function formatFile(value) {
    if ((0, Empty_1.isEmpty)(value)) {
        throw new Empty_1.EmptyError(`Expected File Value!`);
    }
    else if (typeof value === "string") {
        try {
            return dataURIToBlob(value);
        }
        catch (e) {
            return textToBlob(value);
        }
    }
    else if (!(value instanceof Blob)) {
        throw new TypeError("File must be stored in a Blob or string!");
    }
    return value;
}
exports.formatFile = formatFile;
/** Validate Email
 *
 * @param {unknown} value
 * @returns {boolean}
 */
function isFile(value) {
    try {
        formatFile(value);
    }
    catch (e) {
        return false;
    }
    return true;
}
exports.isFile = isFile;
