"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.isTelephone = exports.formatTelephone = void 0;
/** /Validation/Types/Telephone
 *
 * @author Alex Malotky
 */
//Source: https://stackoverflow.com/questions/16699007/regular-expression-to-match-standard-10-digit-phone-number
const TELEPHONE_REGEX = /^(\+?\d{1,2})?\s?[(.]?(\d{3})\)?\s?[.-]?(\d{3})[\s.-]?(\d{4})$/;
/** Format Telephone
 *
 * Used to format / sanitize email input.
 *
 * @param {unknown} value
 * @returns {Telephone}
 */
function formatTelephone(value) {
    if (typeof value !== "string")
        throw new TypeError("Telphone must be stored in a string!");
    const match = value.match(TELEPHONE_REGEX);
    if (match === null)
        throw new TypeError("Telephone is not formated correctly!");
    let country = match[1] || "";
    const number = `(${match[2]}) ${match[3]}-${match[4]}`;
    if (country.length > 0) {
        if (country.charAt(0) !== "+")
            country = "+" + country;
        return country + " " + number;
    }
    return number;
}
exports.formatTelephone = formatTelephone;
/** Validate Telephone
 *
 * @param {unknwon} value
 * @returns {boolean}
 */
function isTelephone(value) {
    try {
        formatTelephone(value);
    }
    catch (e) {
        return false;
    }
    return true;
}
exports.isTelephone = isTelephone;
