/** /Validation
 *
 * @author Alex Malotky
 */
import Type, { Color, Date, DateTime, Email, Telephone, Time, Url, TypeValidator, List, Object, Simple } from "./Type";
import BooleanValidator from "./Boolean";
import NumberValidator from "./Number";
import StringValidator from "./String";
import ColorValidator from "./Color";
import DateValidator from "./Date";
import DateTimeValidator from "./DateTime";
import EmailValidator from "./Email";
import FileValidator from "./File";
import TelephoneValidator from "./Telephone";
import TimeValidator from "./Time";
import UrlValidator from "./Url";
import EmptyValidator from "./Empty";
import ListValidator from "./List";
import ObjectValidator, { ObjectProperties, ObjectDefaults } from "./Object";
import OptionalValidator from "./Optional";
import RecordValidator from "./Record";
export declare function boolean(defaultValue?: boolean): BooleanValidator;
export declare function number(defaultValue?: number): NumberValidator;
export declare function string(defaultValue?: string): StringValidator;
export declare function color(defaultValue?: Color): ColorValidator;
export declare function date(defaultValue?: Date): DateValidator;
export declare function datetime(defaultValue?: DateTime): DateTimeValidator;
export declare function email(defaultValue?: Email): EmailValidator;
export declare function telephone(defaultValue?: Telephone): TelephoneValidator;
export declare function time(defaultValue?: Time): TimeValidator;
export declare function url(defaultValue?: Url): UrlValidator;
export declare function empty(): EmptyValidator;
export declare function file(): FileValidator;
export declare function list<T extends Type>(type: TypeValidator<T>, seperator?: string, defaultValue?: List<T>): ListValidator<T>;
export declare function object<P extends ObjectProperties>(properties: P, defaultValue?: ObjectDefaults<keyof P>): ObjectValidator<P>;
export declare function optional<T extends Type>(type: TypeValidator<T>, defaultValue?: T | null): OptionalValidator<T>;
export declare function record<T extends Type>(type: TypeValidator<T>, defaultValue?: Record<string, T>): RecordValidator<T>;
export type TypeOf<T extends TypeValidator<Type>> = T["_type"];
export type DataConstraints<K extends string | number | symbol> = ObjectDefaults<K>;
export type { ObjectProperties };
/** Data Object
 *
 */
export default class DataObject<P extends ObjectProperties> extends ObjectValidator<P> {
    private _table;
    private _props;
    constructor(tableName: string, properties: P);
    /** Get Table Name
     *
     */
    get name(): string;
    /** Build Constraints
     *
     * @param {DataConstraints} constraints
     * @returns {Array}
     */
    buildConstraints(constraints?: DataConstraints<keyof P>): [string, Simple[]];
    /** Build Insert
     *
     * @param {Object} value
     * @returns {Array}
     */
    buildInsertValues(value: Object<keyof P>): [string, Simple[]];
    /** Build Update
     *
     * @param {Object} value
     * @returns {Array}
     */
    buildUpdateValues(value: Object<keyof P>): [string, Simple[]];
}
