"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.record = exports.optional = exports.object = exports.list = exports.file = exports.empty = exports.url = exports.time = exports.telephone = exports.email = exports.datetime = exports.date = exports.color = exports.string = exports.number = exports.boolean = void 0;
const Boolean_1 = __importDefault(require("./Boolean"));
const Number_1 = __importDefault(require("./Number"));
const String_1 = __importDefault(require("./String"));
const Color_1 = __importDefault(require("./Color"));
const Date_1 = __importDefault(require("./Date"));
const DateTime_1 = __importDefault(require("./DateTime"));
const Email_1 = __importDefault(require("./Email"));
const File_1 = __importDefault(require("./File"));
const Telephone_1 = __importDefault(require("./Telephone"));
const Time_1 = __importDefault(require("./Time"));
const Url_1 = __importDefault(require("./Url"));
const Empty_1 = __importDefault(require("./Empty"));
const List_1 = __importDefault(require("./List"));
const Object_1 = __importDefault(require("./Object"));
const Optional_1 = __importDefault(require("./Optional"));
const Record_1 = __importDefault(require("./Record"));
const Empty_2 = require("./Type/Empty");
//Basic Helper Functions
function boolean(defaultValue) { return new Boolean_1.default(defaultValue); }
exports.boolean = boolean;
;
function number(defaultValue) { return new Number_1.default(defaultValue); }
exports.number = number;
;
function string(defaultValue) { return new String_1.default(defaultValue); }
exports.string = string;
;
function color(defaultValue) { return new Color_1.default(defaultValue); }
exports.color = color;
;
function date(defaultValue) { return new Date_1.default(defaultValue); }
exports.date = date;
;
function datetime(defaultValue) { return new DateTime_1.default(defaultValue); }
exports.datetime = datetime;
;
function email(defaultValue) { return new Email_1.default(defaultValue); }
exports.email = email;
;
function telephone(defaultValue) { return new Telephone_1.default(defaultValue); }
exports.telephone = telephone;
;
function time(defaultValue) { return new Time_1.default(defaultValue); }
exports.time = time;
;
function url(defaultValue) { return new Url_1.default(defaultValue); }
exports.url = url;
;
function empty() { return new Empty_1.default(); }
exports.empty = empty;
;
function file() { return new File_1.default(); }
exports.file = file;
;
//Complex Helper Functions
function list(type, seperator, defaultValue) {
    return new List_1.default(type, seperator, defaultValue);
}
exports.list = list;
function object(properties, defaultValue) {
    return new Object_1.default(properties, defaultValue);
}
exports.object = object;
function optional(type, defaultValue) {
    return new Optional_1.default(type, defaultValue);
}
exports.optional = optional;
function record(type, defaultValue) {
    return new Record_1.default(type, defaultValue);
}
exports.record = record;
/** Data Object
 *
 */
class DataObject extends Object_1.default {
    constructor(tableName, properties) {
        super(properties);
        this._table = tableName;
        this._props = properties;
    }
    /** Get Table Name
     *
     */
    get name() {
        return this._table;
    }
    /** Build Constraints
     *
     * @param {DataConstraints} constraints
     * @returns {Array}
     */
    buildConstraints(constraints) {
        if ((0, Empty_2.isEmpty)(constraints))
            return ["", []];
        let string = "WHERE ";
        const values = [];
        for (const name in constraints) {
            string += name + " = ? AND";
            values.push(this._props[name].simplify(constraints[name]));
        }
        return [string.substring(0, string.length - 3), values];
    }
    /** Build Insert
     *
     * @param {Object} value
     * @returns {Array}
     */
    buildInsertValues(value) {
        let queryNames = "(";
        let queryValues = "VALUES(";
        const values = [];
        for (const name in value) {
            queryNames += name + ", ";
            queryValues += "?, ";
            values.push(this._props[name].simplify(value[name]));
        }
        return [`${queryNames.substring(0, queryNames.length - 2)}) ${queryValues.substring(0, queryValues.length - 2)})`, values];
    }
    /** Build Update
     *
     * @param {Object} value
     * @returns {Array}
     */
    buildUpdateValues(value) {
        let string = "SET ";
        const values = [];
        for (const name in value) {
            string += name + " = ?, ";
            values.push(this._props[name].simplify(value[name]));
        }
        return [string, values];
    }
}
exports.default = DataObject;
