/** /View/HTML/Attributes
 *
 * @author Alex Malotky
 */
import AriaGlobalAttributes from "./Aria";
import { Optional } from "../../../Validation/Type";
type Attribute = string | number | boolean | Array<string> | Date | EventListener;
export default Attribute;
export type AttributeList = Record<string, Optional<Attribute>>;
export type RefferPolicy = "no-referrer" | "no-referrer-when-downgrade" | "origin" | "origin-when-cross-origin" | "unsafe-url";
export type CrossOrigin = "anonymous" | "use-credentials";
export type Priority = "high" | "low" | "auto";
export type Target = "_self" | "_blank" | "_parent" | "_top";
export type SpaceSeperatedList = string | string[];
export type Enumerable = "true" | "false";
export type Value = number | string;
/** Build Attributes String
 *
 * Helper function that converts an Attribute or Init into a string.
 *
 * @param {Dictionary<Attribute>} attributes
 * @returns {stirng}
 */
export declare function buildAttributesString(attributes: AttributeList): string;
/** Attribute To String
 *
 * @param name
 * @param value
 */
export declare function toString(name: string, value: Optional<Attribute>): string;
/** Convert Attribute Name
 *
 * converts camel case names to dash/kebab case.
 *
 * @param {string} name
 * @returns {string}
 */
export declare function convertName(name: string): string;
export interface GlobalAttributes extends AriaGlobalAttributes {
    accesskey?: string;
    autocapitalize?: "none" | "off" | "sentences" | "on" | "words" | "characters";
    autofocus?: boolean;
    class?: SpaceSeperatedList;
    contenteditable?: Enumerable | "plaintext-only";
    dir?: "ltr" | "rtl" | "auto";
    draggable?: Enumerable;
    enterkeyhint?: "enter" | "done" | "go" | "next" | "previous" | "search" | "send";
    exportparts?: SpaceSeperatedList;
    hidden?: boolean | "until-found";
    id?: string;
    inert?: boolean;
    inputmode?: "none" | "text" | "decimal" | "numeric" | "tel" | "search" | "email" | "url";
    is?: string;
    itemid?: string;
    itemprop?: string;
    itemref?: string;
    itemscope?: string;
    itemtype?: string;
    lang?: string;
    nonce?: string;
    part?: SpaceSeperatedList;
    popover?: boolean;
    role?: "toolbar" | "tooltip" | "feed" | "math" | "presentation" | "note" | "scrollbar" | "searchbox" | "separator" | "slider" | "spinbutton" | "switch" | "tab" | "tabpanel" | "treeitem" | "combobox" | "menu" | "menubar" | "tablist" | "tree" | "treegrid";
    slot?: string;
    spellcheck?: boolean;
    style?: string;
    tabindex?: number;
    title?: string;
    translate?: "yes" | "no";
}
