"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.convertName = exports.toString = exports.buildAttributesString = void 0;
/** /View/HTML/Attributes
 *
 * @author Alex Malotky
 */
const Aria_1 = require("./Aria");
const Function_1 = require("../Function");
/** Build Attributes String
 *
 * Helper function that converts an Attribute or Init into a string.
 *
 * @param {Dictionary<Attribute>} attributes
 * @returns {stirng}
 */
function buildAttributesString(attributes) {
    let output = "";
    for (let raw in attributes) {
        const name = convertName(raw);
        const value = attributes[raw];
        if (name.indexOf("aria") >= 0) {
            output += (0, Aria_1.toString)(name, value);
        }
        else {
            output += toString(name, value);
        }
    }
    return output;
}
exports.buildAttributesString = buildAttributesString;
/** Attribute To String
 *
 * @param name
 * @param value
 */
function toString(name, value) {
    switch (typeof value) {
        case "function":
            value = (0, Function_1.toString)(value);
        case "string":
            if (value !== "")
                return " " + name + "=\"" + value.replaceAll('"', "&quot;") + "\"";
            return "";
        case "number":
            if (!isNaN(value))
                return " " + name + "=\"" + value + "\"";
            console.warn("NaN passed as Attribute value!");
            return " " + name + "=\"NaN\" ";
        case "boolean":
            return " " + name;
        case "undefined":
            return "";
        case "object":
            if (Array.isArray(value)) {
                return " " + name + "=\"" + value.join(" ") + "\"";
            }
            else if (value instanceof Date) {
                return " " + name + "=\"" + value.toDateString() + "\"";
            }
            else if (value === null) {
                return " " + name + "=\"\"";
            }
        default:
            console.warn("Unknown value passed as Attribute:\n%o", value);
            return " " + name + "=\"" + String(value) + "\"";
    }
}
exports.toString = toString;
/** Convert Attribute Name
 *
 * converts camel case names to dash/kebab case.
 *
 * @param {string} name
 * @returns {string}
 */
function convertName(name) {
    return name.replaceAll(/([A-Z])/g, ("-$1")).toLocaleLowerCase();
}
exports.convertName = convertName;
