"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.toUpdate = exports.compressContent = void 0;
/** /View/Html/Content
 *
 * @author Alex Malotky
 */
const Function_1 = require("./Function");
const Element_1 = require("./Element");
/** Compress Content
 *
 * @param {Content} content
 * @returns {string}
 */
function compressContent(content) {
    if (Array.isArray(content)) {
        let buffer = "";
        for (let child of content)
            buffer += compressContent(child);
        return buffer;
    }
    else if (content === null || content === undefined) {
        return "";
    }
    else {
        switch (typeof content) {
            case "function":
                return (0, Function_1.toString)(content);
            case "object":
                if ((0, Element_1.isElement)(content)) {
                    return (0, Element_1.compileElement)(content);
                }
                return JSON.stringify(content);
            case "string":
                return content;
            default:
                return String(content);
        }
    }
}
exports.compressContent = compressContent;
/** Convert Content To Update
 *
 * @param {Dictionary<Content>} value
 * @returns {Dictionary<string>|undefined}
 */
function toUpdate(value) {
    if (value === undefined)
        return undefined;
    const output = {};
    for (const name in value) {
        output[name] = compressContent(value[name]);
    }
    return output;
}
exports.toUpdate = toUpdate;
