"use strict";
/** /View/Html/Elements
 *
 * @author Alex Malotky
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.createElement = exports.compileElement = exports.isElement = void 0;
const Attributes_1 = require("../Attributes");
const Content_1 = require("../Content");
function isElement(element) {
    if (typeof element !== "object" || element === null)
        return false;
    if (typeof element.name !== "string") {
        return false;
    }
    if (typeof element.attributes !== "object") {
        return false;
    }
    if (typeof element.selfClosing !== "boolean") {
        return false;
    }
    return Array.isArray(element.children);
}
exports.isElement = isElement;
function compileElement(element) {
    if (element === undefined || typeof element !== "object")
        throw new TypeError("Element must be an object!");
    const { name, selfClosing, attributes, children } = element;
    const attString = (0, Attributes_1.buildAttributesString)(attributes);
    if (selfClosing) {
        if (children.length > 0)
            throw new Error("Self closing Element cannot have children!");
        return "<" + name + attString + "/>";
    }
    return "<" + name + attString + ">" + (0, Content_1.compressContent)(children) + "</" + name + ">";
}
exports.compileElement = compileElement;
function createElement(name, attributes = {}, ...children) {
    name = name.toLocaleLowerCase();
    if (typeof attributes !== "object" || Array.isArray(attributes) || isElement(attributes) || attributes === null) {
        children.unshift(attributes);
        attributes = {};
    }
    if (name === "script" && attributes.env) {
        attributes.type = "javascript/blocked";
    }
    const selfClosing = SELF_CLOSING.indexOf(name) >= 0;
    return { name, selfClosing, attributes, children };
}
exports.createElement = createElement;
/** List of Self CLosing Attributes
 *
 */
const SELF_CLOSING = [
    "area",
    "base",
    "br",
    "col",
    "embed",
    "hr",
    "img",
    "input",
    "link",
    "meta",
    "param",
    "source",
    "track",
    "wbr"
];
