"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.updateMeta = exports.mergeMeta = void 0;
const Util_1 = require("../../../Util");
/** Meta Tag
 *
 * https://developer.mozilla.org/en-US/docs/Web/HTML/Element/script
 * @param {MetaInit} value
 * @returns {HTMLContent}
 */
function Meta(value) {
    if (value.charset) {
        return "<meta charset=\"utf-8\" />";
    }
    if (value.content === undefined)
        throw new Error("Meta must have content!");
    const content = "content=\"" + value.content + "\" ";
    if (value.name !== undefined && value.httpEquiv !== undefined)
        throw new Error("Meta should only have name or http-equiv!");
    let name;
    if (value.name) {
        name = "name=\"" + value.name + "\" ";
    }
    else if (value.httpEquiv) {
        name = "http-equiv=\"" + value.httpEquiv + "\" ";
    }
    else {
        throw new Error("Meta must have a name or http-equiv!");
    }
    return "<meta " + name + content + "/>";
}
exports.default = Meta;
/** Update Meta Tags
 *
 */
function mergeMeta(init = [], update = {}) {
    const output = JSON.parse(JSON.stringify(init));
    const list = Object.getOwnPropertyNames(update);
    for (let i = 0; i < output.length; i++) {
        if (output[i].name) {
            const index = list.indexOf(output[i].name);
            if (index >= 0) {
                output[i].content = update[output[i].name];
                list.splice(index, 1);
            }
        }
    }
    for (let name of list) {
        output.push({
            content: update[name],
            name
        });
    }
    return output;
}
exports.mergeMeta = mergeMeta;
/** Update Meta Tags
 *
 */
function updateMeta(init = [], update = {}) {
    const output = JSON.parse(JSON.stringify(update));
    for (const item of init) {
        if (item.name && item.content && !(0, Util_1.dictionaryInclude)(output, item.name)) {
            output[item.name] = item.content;
        }
    }
    return output;
}
exports.updateMeta = updateMeta;
