"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.mergeUpdateToUpdate = exports.mergeUpdateToInit = void 0;
const Attributes_1 = require("../Attributes");
const Title_1 = __importStar(require("./Title"));
const Base_1 = __importDefault(require("./Base"));
const Link_1 = __importDefault(require("./Link"));
const Style_1 = __importDefault(require("./Style"));
const Script_1 = __importDefault(require("./Script"));
const Meta_1 = __importStar(require("./Meta"));
/** Merge Init with Update
 *
 * @param {I} init
 * @param {U} update
 * @returns {I}
 */
function merge(init = [], update = {}) {
    const output = [];
    const list = Object.getOwnPropertyNames(update);
    for (let original of init) {
        if (original.name) {
            const index = list.indexOf(original.name);
            if (index >= 0) {
                //@ts-ignore
                output.push(update[original.name]);
                list.splice(index, 0);
            }
            else {
                const obj = JSON.parse(JSON.stringify(original));
                delete obj.name;
                output.push(obj);
            }
        }
        else {
            output.push(JSON.parse(JSON.stringify(original)));
        }
    }
    for (let name of list) {
        //@ts-ignore
        output.push({
            ...update[name],
            name
        });
    }
    return output;
}
function toUpdate(value) {
    const output = {};
    for (let item of value) {
        if (item.name) {
            output[item.name] = item;
        }
    }
    return output;
}
/** Merge Init With Update
 *
 * @param {HeadInit} init
 * @param {HeadUpdate} update
 * @returns {HeadInit}
 */
function mergeUpdateToInit(init, update = {}) {
    if (typeof update.styles === "string") {
        update.styles = {
            default: {
                value: update.styles
            }
        };
    }
    return {
        base: init.base,
        title: (0, Title_1.updateTitle)(init.title, update.title),
        meta: (0, Meta_1.mergeMeta)(init.meta, update.meta),
        //@ts-ignore
        links: merge(init.links, update.links),
        styles: merge(init.styles, update.styles),
        scripts: merge(init.scripts, update.scripts)
    };
}
exports.mergeUpdateToInit = mergeUpdateToInit;
/** Merge Init With Update
 *
 * @param {HeadInit} init
 * @param {HeadUpdate} update
 * @returns {HeadInit}
 */
function mergeUpdateToUpdate(init, update = {}) {
    if (typeof update.styles === "string") {
        update.styles = {
            default: {
                value: update.styles
            }
        };
    }
    return {
        title: update.title,
        meta: (0, Meta_1.updateMeta)(init.meta, update.meta),
        //@ts-ignore
        links: toUpdate(merge(init.links, update.links)),
        styles: toUpdate(merge(init.styles, update.styles)),
        scripts: toUpdate(merge(init.scripts, update.scripts))
    };
}
exports.mergeUpdateToUpdate = mergeUpdateToUpdate;
/** Head Tag
 *
 * https://developer.mozilla.org/en-US/docs/Web/HTML/Element/head
 * @param {HeadInit} init
 * @returns {HTMLContent}
 */
function Head(init, att = {}) {
    let content = "";
    if (init.base) {
        content += (0, Base_1.default)(init.base);
    }
    if (init.title) {
        content += (0, Title_1.default)(init.title);
    }
    for (const i of init.meta || []) {
        content += (0, Meta_1.default)(i);
    }
    for (const i of init.links || []) {
        content += (0, Link_1.default)(i);
    }
    for (const i of init.styles || []) {
        content += (0, Style_1.default)(i);
    }
    for (const i of init.scripts || []) {
        content += (0, Script_1.default)(i);
    }
    return "<head" + (0, Attributes_1.buildAttributesString)(att) + ">" + content + "</head>";
}
exports.default = Head;
