"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.HtmlDocument = exports.compressContent = exports.createElement = void 0;
/** /View/Html
 *
 * @author Alex Malotky
 */
const Attributes_1 = require("./Attributes");
const Element_1 = require("./Element");
Object.defineProperty(exports, "createElement", { enumerable: true, get: function () { return Element_1.createElement; } });
const Content_1 = require("./Content");
Object.defineProperty(exports, "compressContent", { enumerable: true, get: function () { return Content_1.compressContent; } });
const Head_1 = __importDefault(require("./Head"));
/** Html Element
 *
 * @param {HTMLInit} init
 * @param {HTMLElement} head
 * @param {HTMLElement} body
 * @returns {HTMLElement}
 */
function html(init, head, body) {
    return "<html" + (0, Attributes_1.buildAttributesString)(init) + ">" + head + body + "</html>";
}
/** Html Body Element
 *
 * @param {Content} children
 * @returns {HTMLElement}
 */
function body(children) {
    return "<body>" + (0, Content_1.compressContent)(children) + "</body>";
}
/** Generate HTML Document
 *
 * @param {Dictionary<string>} att
 * @param {string} head
 * @param {Array<Element|Content>} content
 * @returns {string}
 */
function HtmlDocument(att, head, content) {
    return "<!DOCTYPE html>" + html(att, (0, Head_1.default)(head), body(content));
}
exports.HtmlDocument = HtmlDocument;
