"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
/** /View/RenderEnvironment/Head
 *
 * Front End Head Element
 *
 * @author Alex Malotky
 */
const Util_1 = require("./Util");
const Tacker_1 = __importDefault(require("./Tacker"));
const Scripts_1 = __importDefault(require("./Scripts"));
/** Front End Head Environment Manager
 *
 */
class HeadEnvironment {
    /** Constructor
     *
     */
    constructor() {
        const head = (0, Util_1.findOrCreateElement)("head");
        //Element Trackers
        this._meta = new Tacker_1.default(head, "meta");
        this._links = new Tacker_1.default(head, "links");
        this._styles = new Tacker_1.default(head, "style");
        this._scripts = new Scripts_1.default(head);
        //Title Tracker Attributes
        this._title = head.querySelector("title");
        this._defaultTitle = this._title.textContent || "";
        const index = this._defaultTitle.indexOf("|");
        if (index >= 0) {
            this._defaultTitle = this._defaultTitle.substring(0, index - 1).trim();
        }
    }
    /** Update Head Environment
     *
     * @param {HeadUpdate} update
     */
    async update(update) {
        if (this._defaultTitle === "") {
            this._title.textContent = update.title || "";
        }
        else if (update.title === undefined || update.title === "") {
            this._title.textContent = this._defaultTitle;
        }
        else {
            this._title.textContent = this._defaultTitle + " | " + update.title;
        }
        const meta = {};
        for (let name in update.meta) {
            meta[name] = {
                content: update.meta[name]
            };
        }
        this._meta.update(meta);
        this._links.update(update.links);
        this._styles.update(update.styles);
        await this._scripts.update(update.scripts);
    }
}
exports.default = HeadEnvironment;
