"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/** /View/RenderEnvironment/Tracker
 *
 * Front End Element Tracker
 *
 * @author Alex Malotky
 */
const Util_1 = require("./Util");
/** Header Sub Element Tracker
 *
 */
class Tracker {
    /** Tracker Constructor
     *
     * @param {HTMLElement} head
     * @param {string} name
     */
    constructor(head, name) {
        this._current = {};
        this._name = name;
        for (const element of Array.from(head.querySelectorAll(name))) {
            const name = element.getAttribute("name");
            if (name) {
                const defaults = {};
                for (let att of element.getAttributeNames()) {
                    defaults[att] = element.getAttribute(att) || undefined;
                }
                this._current[name] = element;
            }
        }
    }
    /** Update Tracked Elements
     *
     * @param {Record<string, AttributeList>} updates
     */
    update(updates) {
        const lstUpdate = Object.getOwnPropertyNames(updates);
        //Loop over current tags
        for (let name in this._current) {
            const index = lstUpdate.indexOf(name);
            //If being updated
            if (index !== -1) {
                Tracker.updateElement(this._current[name], updates[name]);
                lstUpdate.splice(index, 1);
                //If had default value
            }
            else {
                this._current[name].parentElement.removeChild(this._current[name]);
                delete this._current[name];
            }
        }
        //Loop through tags to add
        for (let name of lstUpdate) {
            this._current[name] = (0, Util_1.findOrCreateElement)(`${this._name}[name='${name}']`, "head");
            Tracker.updateElement(this._current[name], updates[name]);
        }
    }
    /** Update Element
     *
     * @param {Element} element
     * @param {AttributeList} update
     */
    static updateElement(element, update = {}) {
        if (update.value) {
            element.innerHTML = update.value;
            delete update.value;
        }
        const lstUpdate = Object.getOwnPropertyNames(update);
        for (let name of element.getAttributeNames()) {
            const index = lstUpdate.indexOf(name);
            if (index !== -1) {
                element.setAttribute(name, String(update[name]));
                lstUpdate.splice(index, 1);
            }
            else {
                element.removeAttribute(name);
            }
        }
        for (let name of lstUpdate) {
            element.setAttribute(name, String(update[name]));
        }
    }
}
exports.default = Tracker;
