/** /View/RenderEnvironment
 *
 * Front End Environment
 *
 * @author Alex Malotky
 */
import { FetchUpdate } from "..";
interface FetchOptions extends RequestInit {
    headers?: Record<string, string>;
}
/** Front End Render Environment
 *
 */
export default class RenderEnvironment {
    private _head;
    private _headHash;
    private _bodyHash;
    private _events;
    private _routing;
    private _delay;
    /** Render Environment Constructor
     *
     */
    constructor();
    /** Main Route Handler
     *
     * Returns value if there is an anchor to scroll too.
     *
     * @param {FormData} body
     * @returns {Promise<string|undefined>}
     */
    handler(url?: string | URL, body?: FormData): Promise<string | undefined>;
    /** Route to locale page.
     *
     * @param {string|URL} url
     * @param {FormData} body
     */
    route(url: string | URL, body?: FormData): void;
    /** Scroll to Element
     *
     * @param {string} id
     */
    scroll(id: string): void;
    /** Open External Link
     *
     * @param {string|URL} href
     */
    link(href: string | URL): void;
    /** Run Script
     *
     * @param script
     */
    run(script: string): void;
    /** Add Event
     *
     * @param update
     */
    event(type: string, listener: EventListener): void;
    /** Update Environment
     *
     * @param {RenderUpdate} update
     */
    update(update: FetchUpdate): Promise<void>;
    /** Update Head
     *
     * @param {HeadUpdate} update
     */
    private updateHead;
    /** Update Body
     *
     */
    private updateBody;
    /** Run Scripts
     *
     * @param {RegExpMatchArray} update
     */
    private scripts;
    /** Clear Events
     *
     */
    private clear;
    /** Assign Render Content to Target
     *
     * @param {HTMLElement} target
     * @param {RenderContent} content
     */
    static render(target: HTMLElement & {
        value?: string;
    }, content: string): void;
    /** Fetch Wrapper
     *
     * @param {stirng|URL} url
     * @param {FetchOptions} opts
     * @returns {Promise<RenderUpdate>}
     */
    static fetch(url: string | URL, opts: FetchOptions): Promise<FetchUpdate>;
    /** Display Error
     *
     * @param {any} value
     */
    static error(value: any): void;
}
export {};
