/** /View
 *
 * @author Alex Malotky
 */
import { HTMLInit } from "./Html";
import Content from "./Html/Content";
import { HeadInit, HeadUpdate } from "./Html/Head";
import Context from "../Context";
import Layer from "../Routing/Layer";
export type RenderFunction = (update: Record<string, Content>) => Content;
export interface RenderUpdate {
    head?: HeadUpdate;
    body?: Record<string, Content>;
    redirect?: string;
    update?: Record<string, Content>;
}
export interface FetchUpdate {
    head: HeadUpdate;
    body?: Record<string, string>;
    redirect?: string;
    update?: Record<string, string>;
}
/** View Class
 *
 */
export default class View {
    #private;
    static readonly injectFilePath = "/zim.js";
    private static readonly injectedFileRoute;
    private static readonly injectedFileType;
    private static readonly injectedFileContent;
    /** Inject Web File
     *
     * @param {Context} ctx
     */
    static injectFile(ctx: Context): void;
    /** Constructor
     *
     * @param {HTMLInit} attributes
     * @param {HeadInit} headInit
     * @param {RenderFunction} renderContent
     */
    constructor(attributes?: HTMLInit, headInit?: HeadInit, renderContent?: RenderFunction);
    /** Set Up File Injection
     *
     * @returns {Layer}
     */
    setUpInjection(): Layer;
    /** Render Content
     *
     * @param {RenderUpdate} update
     * @returns {string}
     */
    render(update: RenderUpdate): string;
    /** Update Content
     *
     * @param {RenderUpdate} update
     * @returns {FetchUpdate}
     */
    update(value: RenderUpdate): FetchUpdate;
}
