"use strict";
var __classPrivateFieldSet = (this && this.__classPrivateFieldSet) || function (receiver, state, value, kind, f) {
    if (kind === "m") throw new TypeError("Private method is not writable");
    if (kind === "a" && !f) throw new TypeError("Private accessor was defined without a setter");
    if (typeof state === "function" ? receiver !== state || !f : !state.has(receiver)) throw new TypeError("Cannot write private member to an object whose class did not declare it");
    return (kind === "a" ? f.call(receiver, value) : f ? f.value = value : state.set(receiver, value)), value;
};
var __classPrivateFieldGet = (this && this.__classPrivateFieldGet) || function (receiver, state, kind, f) {
    if (kind === "a" && !f) throw new TypeError("Private accessor was defined without a getter");
    if (typeof state === "function" ? receiver !== state || !f : !state.has(receiver)) throw new TypeError("Cannot read private member from an object whose class did not declare it");
    return kind === "m" ? f : kind === "a" ? f.call(receiver) : f ? f.value : state.get(receiver);
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
var _View_defaultHead, _View_defaultContent, _View_attribute;
Object.defineProperty(exports, "__esModule", { value: true });
/** /View
 *
 * @author Alex Malotky
 */
const Html_1 = require("./Html");
const Content_1 = require("./Html/Content");
const Head_1 = require("./Html/Head");
const Util_1 = require("../Util");
const Node_1 = require("../Node");
const MimeTypes_1 = __importDefault(require("../MimeTypes"));
const Layer_1 = __importDefault(require("../Routing/Layer"));
const { version } = require("../../package.json");
/** Get Web File
 *
 * Different Implementation depending on environment.
 *
 * @returns {string}
 */
function getFile() {
    if ((0, Util_1.inCloudfareWorker)()) {
        return require("!raw-loader!./Web.js").default;
    }
    const fs = (0, Node_1.nodeImport)("fs");
    const path = (0, Node_1.nodeImport)("path");
    return fs.readFileSync(path.join(__dirname, "Web.js")).toString();
}
/** View Class
 *
 */
class View {
    /** Inject Web File
     *
     * @param {Context} ctx
     */
    static injectFile(ctx) {
        ctx.response.headers.set("Content-Type", View.injectedFileType);
        ctx.write(View.injectedFileContent);
        ctx.end();
    }
    /** Constructor
     *
     * @param {HTMLInit} attributes
     * @param {HeadInit} headInit
     * @param {RenderFunction} renderContent
     */
    constructor(attributes = {}, headInit = {}, renderContent = () => null) {
        _View_defaultHead.set(this, void 0);
        _View_defaultContent.set(this, void 0);
        _View_attribute.set(this, void 0);
        if (typeof attributes !== "object")
            throw new TypeError("Invalid Attributes!");
        if (typeof headInit !== "object")
            throw new TypeError("Invalid Head Attributes");
        if (typeof renderContent !== "function")
            throw new TypeError("Render Content must be in the form of a function!");
        __classPrivateFieldSet(this, _View_defaultContent, renderContent, "f");
        __classPrivateFieldSet(this, _View_attribute, attributes, "f");
        __classPrivateFieldSet(this, _View_defaultHead, headInit, "f");
    }
    /** Set Up File Injection
     *
     * @returns {Layer}
     */
    setUpInjection() {
        if (__classPrivateFieldGet(this, _View_defaultHead, "f").scripts === undefined)
            __classPrivateFieldGet(this, _View_defaultHead, "f").scripts = [];
        let exsits = false;
        for (const scripts of __classPrivateFieldGet(this, _View_defaultHead, "f").scripts) {
            if (scripts.src === View.injectedFileRoute) {
                exsits = true;
                break;
            }
        }
        if (!exsits) {
            __classPrivateFieldGet(this, _View_defaultHead, "f").scripts.push({ src: View.injectedFileRoute, defer: true });
        }
        return new Layer_1.default(View.injectFilePath, View.injectFile);
    }
    /** Render Content
     *
     * @param {RenderUpdate} update
     * @returns {string}
     */
    render(update) {
        return (0, Html_1.HtmlDocument)(__classPrivateFieldGet(this, _View_attribute, "f"), (0, Head_1.mergeUpdateToInit)(__classPrivateFieldGet(this, _View_defaultHead, "f"), update.head), __classPrivateFieldGet(this, _View_defaultContent, "f").call(this, update.body || {}));
    }
    /** Update Content
     *
     * @param {RenderUpdate} update
     * @returns {FetchUpdate}
     */
    update(value) {
        return {
            head: (0, Head_1.mergeUpdateToUpdate)(__classPrivateFieldGet(this, _View_defaultHead, "f"), value.head),
            body: (0, Content_1.toUpdate)(value.body),
            redirect: value.redirect,
            update: (0, Content_1.toUpdate)(value.update)
        };
    }
}
_View_defaultHead = new WeakMap(), _View_defaultContent = new WeakMap(), _View_attribute = new WeakMap();
View.injectFilePath = "/zim.js";
View.injectedFileRoute = `/zim.js?${version}`;
View.injectedFileType = (0, MimeTypes_1.default)("js");
View.injectedFileContent = getFile();
exports.default = View;
