/// <reference types="./global.d.ts" />
/** /Engine
 *
 * @author Alex Malotky
 */
import Routing from "./Routing";
import Context, { NodeRequeset, NodeResponse } from "./Context";
import View, { RenderUpdate } from "./View";
import { Middleware } from "./Routing/Layer";
import Authorization from "./Authorization";
import RenderEnvironment from "./View/RenderEnvironment";
import Router from "./Routing/Router";
import { createElement } from "./View/Html/Element";
import Content from "./View/Html/Content";
import HttpError from "./HttpError";
export { Router, Context, createElement, HttpError, View, Authorization };
export type { Content, Middleware, RenderEnvironment, RenderUpdate };
/** Engine Class
 *
 */
export default class Engine extends Routing {
    private _view;
    private _auth;
    private _env;
    /**
     *
     */
    constructor();
    /** View Setter
     *
     * @param {View} value
     */
    view(value: View, inject?: boolean): void;
    /** Auth Setter
     *
     * @param {View} value
     */
    auth(value: Authorization): void;
    /** Environemnt Setter
     *
     * @param {string} key
     * @param {any} value
     */
    env(key: string, value: any): void;
    /** Cloudflare Fetch Response Environment
     *
     * @param {Request} req
     * @param {Env} env
     * @returns {Promise<Response>}
     */
    fetch(req: Request, env: Env): Promise<Response>;
    /** Get Node Server Environment
     *
     */
    get server(): (req: NodeRequeset, res: NodeResponse) => Promise<Response | undefined>;
    /** Start of Handler Environment
     *
     * @param {NodeRequeset|Request} req
     * @param {NodeResponse|undefined} res
     * @param {Env} env
     * @returns {Response|undefined}
     */
    private start;
}
