"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Authorization = exports.View = exports.HttpError = exports.createElement = exports.Context = exports.Router = void 0;
/** /Engine
 *
 * @author Alex Malotky
 */
const Routing_1 = __importDefault(require("./Routing"));
const Context_1 = __importDefault(require("./Context"));
exports.Context = Context_1.default;
const View_1 = __importDefault(require("./View"));
exports.View = View_1.default;
const Authorization_1 = __importDefault(require("./Authorization"));
exports.Authorization = Authorization_1.default;
const Util_1 = require("./Util");
//Exports
const Router_1 = __importDefault(require("./Routing/Router"));
exports.Router = Router_1.default;
const Element_1 = require("./View/Html/Element");
Object.defineProperty(exports, "createElement", { enumerable: true, get: function () { return Element_1.createElement; } });
const HttpError_1 = __importDefault(require("./HttpError"));
exports.HttpError = HttpError_1.default;
/** Engine Class
 *
 */
class Engine extends Routing_1.default {
    /**
     *
     */
    constructor() {
        super();
        this._env = {};
    }
    /** View Setter
     *
     * @param {View} value
     */
    view(value, inject = true) {
        if (!(value instanceof View_1.default))
            throw new Error("Value must be an instance of View!");
        if (inject) {
            const layer = value.setUpInjection();
            if (this._methods.length === 0 || this._methods.at(0).layer.path !== View_1.default.injectFilePath) {
                this._methods.unshift({
                    name: "ALL",
                    layer: layer
                });
            }
        }
        this._view = value;
    }
    /** Auth Setter
     *
     * @param {View} value
     */
    auth(value) {
        if (!(value instanceof Authorization_1.default))
            throw new TypeError("Value must be an instance of Authorization!");
        if (typeof value.get() !== "function")
            throw new TypeError("Authentication Getter is not set!");
        this._auth = value;
    }
    /** Environemnt Setter
     *
     * @param {string} key
     * @param {any} value
     */
    env(key, value) {
        if ((0, Util_1.inCloudfareWorker)())
            throw new Error("Cannot setup envrionment in cloudflare worker!");
        this._env[key] = value;
    }
    /** Cloudflare Fetch Response Environment
     *
     * @param {Request} req
     * @param {Env} env
     * @returns {Promise<Response>}
     */
    async fetch(req, env) {
        if (env.ASSETS) {
            const assetResponse = await env.ASSETS.fetch(req.clone());
            if (assetResponse.status < 400)
                return assetResponse;
        }
        return (await this.start(req, undefined, env));
    }
    /** Get Node Server Environment
     *
     */
    get server() {
        return async (req, res) => await this.start(req, res);
    }
    /** Start of Handler Environment
     *
     * @param {NodeRequeset|Request} req
     * @param {NodeResponse|undefined} res
     * @param {Env} env
     * @returns {Response|undefined}
     */
    async start(req, res, env) {
        return await this.route(new Context_1.default(req, res, env || this._env, this._view, this._auth));
    }
}
exports.default = Engine;
